

## ------------------------------------------------------------------------ ##
##  R scripts for " Multidimenional smoothing by adaptive local kernel      ##
##                weighted log-likelihood: Application to long-term care    ##
##                insurance "                                               ##
## ------------------------------------------------------------------------ ##
##  Script        Scripts to obtain markers  -  Script n•05                 ##
## ------------------------------------------------------------------------ ##
##  Description   Script to obtain the survival function by age of          ##
##                occurence, period life expectancy and other markers       ##
## ------------------------------------------------------------------------ ##
##  Author        Tomas Julien                                              ##
## ------------------------------------------------------------------------ ##
##  Version       01 - 30/08/2012                                           ##
## ------------------------------------------------------------------------ ##

## ---------------- If necessary,

rm(list=ls(all=TRUE))

## ------------------------------------------------------------------------ ##
##           	       Change the workspace repository                      ##
## ------------------------------------------------------------------------ ##

setwd("...") # ! to be added !

## ------------------------------------------------------------------------ ##
##           	               Load functions                               ##
## ------------------------------------------------------------------------ ##

## --- Miscellaneous functions

source("misc_functions.R")

## --- Graphic functions

require(lattice); require(grid); require(latticeExtra)

## --- Load X11 options

X11.options(type="nbcairo",family="FreeSans")


## ------------------------------------------------------------------------ ##
##             	                  Load data                                 ##
## ------------------------------------------------------------------------ ##

## ------------------ Set age of occurence and duration (months)

Occ <- 70:90; Dur <- 0:119

## ------------------ Load data

load("Data/Original data/dij.RData")
load("Data/Original data/eij.RData")
load("Data/Original data/muij.RData")
load("Data/Original data/qhatij.RData")

Mu_i.j_hat_tech <- (2*Qhat_i.j)/(2-Qhat_i.j)

## ------------------ Load fitted values

load("Data/Smoothed data/Mu_i.j_hat_lk.RData")
load("Data/Smoothed data/Mu_i.j_hat_ps.RData")
load("Data/Smoothed data/Mu_i.j_hat_ici.RData")
load("Data/Smoothed data/Mu_i.j_hat_bf.RData")

Mu_i.j_list <- vector("list",6)

Mu_i.j_list[[1]] <- Mu_i.j
Mu_i.j_list[[2]] <- Mu_i.j_hat_lk
Mu_i.j_list[[3]] <- Mu_i.j_hat_ps
Mu_i.j_list[[4]] <- Mu_i.j_hat_ici
Mu_i.j_list[[5]] <- Mu_i.j_hat_bf
Mu_i.j_list[[6]] <- Mu_i.j_hat_tech

for (i in 1:6){ colnames(Mu_i.j_list[[i]]) <- as.character(Occ) }

## ------------------ Load graphical parameters

names.models <- c("Local lik.", "P-splines", "Local lik. ICI", "Local lik. BF")

col.vec <- c(1,2,3,4,6, "orange")
lty.vec <- c(1,1,1,1,1,1)
leg.vec <- c("Observed",names.models,"Tech. report")

## ------------------------------------------------------------------------ ##
##           	               Survival function                            ##
## ------------------------------------------------------------------------ ##

## ------------------ Obtain the survival function for each age of occurence

surv.f <- vector("list",6)
for(i in 1:6){
	surv.f[[i]] <- matrix(,length(Dur),length(Occ))
	colnames(surv.f[[i]]) <- as.character(Occ)
	for(j in 1:length(Occ)){
		surv.f[[i]][,j] <- survi.fct(1-exp(-Mu_i.j_list[[i]][Dur+1, j]), E_i.j[1,j], Dur) } }
		
## ------------------ Surface plot

## --- Observations

x11();
surface_plot(surv.f[[1]], "Survival function - Observations", c(min(Dur),max(Dur),min(Occ),max(Occ)))

## --- Local lik.

x11();
surface_plot(surv.f[[2]], "Survival function - Local lik.", c(min(Dur),max(Dur),min(Occ),max(Occ)))

## --- P-splines

x11();
surface_plot(surv.f[[3]], "Survival function - P-splines", c(min(Dur),max(Dur),min(Occ),max(Occ)))

## --- Local lik. ICI

x11();
surface_plot(surv.f[[4]], "Survival function - Local lik. ICI", c(min(Dur),max(Dur),min(Occ),max(Occ)))

## --- Local lik. BF

x11();
surface_plot(surv.f[[5]], "Survival function - Local lik. BF", c(min(Dur),max(Dur),min(Occ),max(Occ)))

## --- Technical report

x11();
surface_plot(surv.f[[6]], "Survival function - Technical report", c(min(Dur),max(Dur),min(Occ),max(Occ)))

## ------------------ Graphical comparison for a particular age of occurence

## --- Choose an age of occurence

yy <- 70

x11();
comp.plot.sf.occ(surv.f, yy , c(135,140), col.vec, lty.vec, leg.vec, Dur, c(-0.02,1.03))

## ------------------ Graphical comparison for a particular duration

## --- Choose a duration (months)

xx <- 36

x11();
comp.plot.sf.dur(surv.f, xx , c(135,140), col.vec, lty.vec, leg.vec, Occ, c(0.3,0.5))

## ------------------------------------------------------------------------ ##
##           	                Life expectancy                             ##
## ------------------------------------------------------------------------ ##

## ---------------- For all duration

ple <- vector("list",6)
for(i in 1:6){
	ple[[i]] <- period.l.e(Mu_i.j_list[[i]],Dur,Occ)
	colnames(ple[[i]]) <- as.character(Occ)
}

## --- choose duration and age of occurence

xx <- 0; yy <- 90
for (i in 1:6){ print( c(leg.vec[i],ple[[i]][xx+1,as.character(yy)]))}

xx <- 0;

for (i in 1:6){ print( c(leg.vec[i],mean(ple[[i]][xx+1,])))}

## ------------------ Graphical comparison for a particular age of occurence

## --- Choose an age of occurence

yy <- 80

x11();
comp.plot.ple.occ(ple, yy , c(50,45), col.vec, lty.vec, leg.vec, Dur, c(0,50))

## ------------------ Graphical comparison for a particular duration

## --- Choose a duration (months)

xx <- 1

x11();
comp.plot.ple.dur(ple, xx , c(135,140), col.vec, lty.vec, leg.vec, Occ, c(27,55))

## ------------------------------------------------------------------------ ##
##          	             Median month at death                          ##
## ------------------------------------------------------------------------ ##

## - Assumption for non-integer ages 
## - Uniform distribution of death:

S.xx <- vector("list",6)
for(i in 1:6){
		S.xx[[i]] <- vector("list",2)
		S.xx[[i]][[1]] <- S.xx[[i]][[2]] <- matrix(,(length(Dur)-1)*100,length(Occ))
		for(j in 1:length(Occ)){
			tt <- get.s.xx(t(surv.f[[i]][,j]),c(0,119))
			S.xx[[i]][[1]][,j] <- tt$a.xx
			S.xx[[i]][[2]][,j] <- tt$s.xx } }
	
med.month <- matrix(,length(Occ),6)
rownames(med.month) <- as.character(Occ); colnames(med.month) <- leg.vec
for (i in 1:6) {
	for(j in 1:length(Occ)){
	med.month[j,i] <- S.xx[[i]][[1]][max(which(S.xx[[i]][[2]][,j] >= 0.5))+1, j] } }

med.month

for(i in 1:6){ print(c(leg.vec[i],mean(med.month[,i]))) }

## ------------------ Graphical comparison for the month median at death

x11();
comp.plot.med.month(med.month, c(135,40), col.vec, lty.vec, leg.vec, Occ, c(11,34))

## ------------------------------------------------------------------------ ##
##          	   Standard deviation of the random lifetime                ##
## ------------------------------------------------------------------------ ##

## ---------------- Standard deviation of the random lifetime

sd.Fx <- matrix(,length(Occ),6)
rownames(sd.Fx) <- as.character(Occ)
colnames(sd.Fx) <- leg.vec
for (i in 1:6) {
	for(j in 1:length(Occ)){
		sd.Fx[j,i] <- sqrt(var(1-surv.f[[i]][,j])) } }
		
sd.Fx

for(i in 1:6){ print(c(leg.vec[i],mean(sd.Fx[,i]))) }


## ------------------ Graphical comparison for the standard deviation of the random lifetime

x11();
comp.plot.sd.Fx(sd.Fx, c(50,140), col.vec, lty.vec, leg.vec, Occ, c(0.16,0.27))

## ------------------------------------------------------------------------ ##
##          	                  Entropy                                   ##
## ------------------------------------------------------------------------ ##

H.Fx <- matrix(,length(Occ),6)
rownames(H.Fx) <- as.character(Occ)
colnames(H.Fx) <- leg.vec
for (i in 1:6) {
	for(j in 1:length(Occ)){
		H.Fx[j,i] <- - mean(log(surv.f[[i]][,j]))/ sum(surv.f[[i]][,j]) } }
		
H.Fx

for(i in 1:6){ print(c(leg.vec[i],mean(H.Fx[,i]))) }


## ------------------ Graphical comparison for the entropy

x11();
comp.plot.H.Fx(H.Fx, c(50,140), col.vec, lty.vec, leg.vec, Occ, c(.02,0.07))








